@@ -122,9 +122,6 @@ void TestDataDevice::init()
     QVERIFY(pointerChangedSpy.wait());
 
     m_compositorInterface = m_display->createCompositor(m_display);
-    m_compositorInterface->create();
-    QVERIFY(m_compositorInterface->isValid());
-
     QVERIFY(compositorSpy.wait());
     m_compositor = registry.createCompositor(compositorSpy.first().first().value<quint32>(),
                                              compositorSpy.first().last().value<quint32>(), this);
@@ -184,9 +181,11 @@ void TestDataDevice::testCreate()
     QVERIFY(!deviceInterface->selection());
     QVERIFY(deviceInterface->parentResource());
 
+
+    // this will probably fail, we need to make a selection client side
     QVERIFY(!m_seatInterface->selection());
-    m_seatInterface->setSelection(deviceInterface);
-    QCOMPARE(m_seatInterface->selection(), deviceInterface);
+    m_seatInterface->setSelection(deviceInterface->selection());
+    QCOMPARE(m_seatInterface->selection(), deviceInterface->selection());
 
     // and destroy
     QSignalSpy destroyedSpy(deviceInterface, &QObject::destroyed);
@@ -404,7 +403,7 @@ void TestDataDevice::testSetSelection()
     // send selection to datadevice
     QSignalSpy selectionOfferedSpy(dataDevice.data(), SIGNAL(selectionOffered(KWayland::Client::DataOffer*)));
     QVERIFY(selectionOfferedSpy.isValid());
-    deviceInterface->sendSelection(deviceInterface);
+    deviceInterface->sendSelection(deviceInterface->selection());
     QVERIFY(selectionOfferedSpy.wait());
     QCOMPARE(selectionOfferedSpy.count(), 1);
     auto dataOffer = selectionOfferedSpy.first().first().value<DataOffer*>();
@@ -439,7 +438,7 @@ void TestDataDevice::testSetSelection()
     dataDevice.reset();
     QVERIFY(unboundSpy.wait());
     // send a selection to the unbound data device
-    deviceInterface->sendSelection(deviceInterface);
+    deviceInterface->sendSelection(deviceInterface->selection());
 }
 
 void TestDataDevice::testSendSelectionOnSeat()
