@@ -20,7 +20,7 @@
 #include "../../src/server/buffer_interface.h"
 #include "../../src/server/compositor_interface.h"
 #include "../../src/server/display.h"
-#include "../../src/server/idleinhibit_interface.h"
+#include "../../src/server/idleinhibit_v1_interface.h"
 #include "../../src/server/surface_interface.h"
 // Wayland
 #include <wayland-client-protocol.h>
@@ -57,7 +57,7 @@ private Q_SLOTS:
 private:
     KWaylandServer::Display *m_display;
     KWaylandServer::CompositorInterface *m_compositorInterface;
-    KWaylandServer::IdleInhibitManagerInterface *m_idleInhibitInterface;
+    KWaylandServer::IdleInhibitManagerV1Interface *m_idleInhibitInterface;
     KWayland::Client::ConnectionThread *m_connection;
     KWayland::Client::Compositor *m_compositor;
     KWayland::Client::ShmPool *m_shm;
@@ -90,13 +90,9 @@ void TestWaylandSurface::init()
 
     m_compositorInterface = m_display->createCompositor(m_display);
     QVERIFY(m_compositorInterface);
-    m_compositorInterface->create();
-    QVERIFY(m_compositorInterface->isValid());
 
-    m_idleInhibitInterface = m_display->createIdleInhibitManager(IdleInhibitManagerInterfaceVersion::UnstableV1, m_display);
+    m_idleInhibitInterface = m_display->createIdleInhibitManagerV1(m_display);
     QVERIFY(m_idleInhibitInterface);
-    m_idleInhibitInterface->create();
-    QVERIFY(m_idleInhibitInterface->isValid());
 
     // setup connection
     m_connection = new KWayland::Client::ConnectionThread;
@@ -228,6 +224,9 @@ void TestWaylandSurface::testStaticAccessor()
     QCOMPARE(KWaylandServer::SurfaceInterface::get(serverSurface2->resource()), serverSurface2);
     QCOMPARE(KWaylandServer::SurfaceInterface::get(serverSurface2->id(), serverSurface2->client()), serverSurface2);
 
+    const quint32 surfaceId1 = serverSurface1->id();
+    const quint32 surfaceId2 = serverSurface2->id();
+
     // delete s2 again
     delete s2;
     QCOMPARE(KWayland::Client::Surface::all().count(), 1);
@@ -238,11 +237,12 @@ void TestWaylandSurface::testStaticAccessor()
     delete s1;
     QVERIFY(KWayland::Client::Surface::all().isEmpty());
     QVERIFY(!KWayland::Client::Surface::get(nullptr));
-    QSignalSpy unboundSpy(serverSurface1, &KWaylandServer::Resource::unbound);
-    QVERIFY(unboundSpy.isValid());
-    QVERIFY(unboundSpy.wait());
+    QSignalSpy destroyedSpy(serverSurface1, &KWaylandServer::SurfaceInterface::destroyed);
+    QVERIFY(destroyedSpy.isValid());
+    QVERIFY(destroyedSpy.wait());
     QVERIFY(!KWaylandServer::SurfaceInterface::get(nullptr));
-    QVERIFY(!KWaylandServer::SurfaceInterface::get(1, nullptr));
+    QVERIFY(!KWaylandServer::SurfaceInterface::get(surfaceId1, nullptr));
+    QVERIFY(!KWaylandServer::SurfaceInterface::get(surfaceId2, nullptr));
 }
 
 void TestWaylandSurface::testDamage()
@@ -255,7 +255,6 @@ void TestWaylandSurface::testDamage()
     KWaylandServer::SurfaceInterface *serverSurface = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface*>();
     QVERIFY(serverSurface);
     QCOMPARE(serverSurface->damage(), QRegion());
-    QVERIFY(serverSurface->parentResource());
     QVERIFY(!serverSurface->isMapped());
 
     QSignalSpy committedSpy(serverSurface, SIGNAL(committed()));
@@ -732,24 +731,24 @@ void TestWaylandSurface::testScale()
     QVERIFY(serverSurfaceCreated.wait());
     SurfaceInterface *serverSurface = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface*>();
     QVERIFY(serverSurface);
-    QCOMPARE(serverSurface->scale(), 1);
+    QCOMPARE(serverSurface->bufferScale(), 1);
 
     // let's change the scale factor
-    QSignalSpy scaleChangedSpy(serverSurface, &SurfaceInterface::scaleChanged);
+    QSignalSpy bufferScaleChangedSpy(serverSurface, &SurfaceInterface::bufferScaleChanged);
 
     //changing the scale implicitly changes the size
     QSignalSpy sizeChangedSpy(serverSurface, &SurfaceInterface::sizeChanged);
 
-    QVERIFY(scaleChangedSpy.isValid());
+    QVERIFY(bufferScaleChangedSpy.isValid());
     s->setScale(2);
     QCOMPARE(s->scale(), 2);
     // needs a commit
-    QVERIFY(!scaleChangedSpy.wait(100));
+    QVERIFY(!bufferScaleChangedSpy.wait(100));
     s->commit(Surface::CommitFlag::None);
-    QVERIFY(scaleChangedSpy.wait());
-    QCOMPARE(scaleChangedSpy.count(), 1);
-    QCOMPARE(scaleChangedSpy.first().first().toInt(), 2);
-    QCOMPARE(serverSurface->scale(), 2);
+    QVERIFY(bufferScaleChangedSpy.wait());
+    QCOMPARE(bufferScaleChangedSpy.count(), 1);
+    QCOMPARE(bufferScaleChangedSpy.first().first().toInt(), 2);
+    QCOMPARE(serverSurface->bufferScale(), 2);
 
     //even though we've changed the scale, if we don't have a buffer we
     //don't have a size. If we don't have a size it can't have changed
@@ -759,17 +758,17 @@ void TestWaylandSurface::testScale()
     // let's try changing to same factor, should not emit changed on server
     s->setScale(2);
     s->commit(Surface::CommitFlag::None);
-    QVERIFY(!scaleChangedSpy.wait(100));
+    QVERIFY(!bufferScaleChangedSpy.wait(100));
 
     // but changing to a different value should still work
     s->setScale(4);
     s->commit(Surface::CommitFlag::None);
-    QVERIFY(scaleChangedSpy.wait());
-    QCOMPARE(scaleChangedSpy.count(), 2);
-    QCOMPARE(scaleChangedSpy.first().first().toInt(), 2);
-    QCOMPARE(scaleChangedSpy.last().first().toInt(), 4);
-    QCOMPARE(serverSurface->scale(), 4);
-    scaleChangedSpy.clear();
+    QVERIFY(bufferScaleChangedSpy.wait());
+    QCOMPARE(bufferScaleChangedSpy.count(), 2);
+    QCOMPARE(bufferScaleChangedSpy.first().first().toInt(), 2);
+    QCOMPARE(bufferScaleChangedSpy.last().first().toInt(), 4);
+    QCOMPARE(serverSurface->bufferScale(), 4);
+    bufferScaleChangedSpy.clear();
 
     //attach a buffer of 100x100, our scale is 4, so this should be a size of 25x25
     QImage red(100, 100, QImage::Format_ARGB32_Premultiplied);
@@ -783,18 +782,18 @@ void TestWaylandSurface::testScale()
     QCOMPARE(sizeChangedSpy.count(), 1);
     QCOMPARE(serverSurface->size(), QSize(25,25));
     sizeChangedSpy.clear();
-    scaleChangedSpy.clear();
+    bufferScaleChangedSpy.clear();
 
     //set the scale to 1, buffer is still 100x100 so size should change to 100x100
     s->setScale(1);
     s->commit(Surface::CommitFlag::None);
     QVERIFY(sizeChangedSpy.wait());
     QCOMPARE(sizeChangedSpy.count(), 1);
-    QCOMPARE(scaleChangedSpy.count(), 1);
-    QCOMPARE(serverSurface->scale(), 1);
+    QCOMPARE(bufferScaleChangedSpy.count(), 1);
+    QCOMPARE(serverSurface->bufferScale(), 1);
     QCOMPARE(serverSurface->size(), QSize(100,100));
     sizeChangedSpy.clear();
-    scaleChangedSpy.clear();
+    bufferScaleChangedSpy.clear();
 
     //set scale and size in one commit, buffer is 50x50 at scale 2 so size should be 25x25
     QImage blue(50, 50, QImage::Format_ARGB32_Premultiplied);
@@ -806,8 +805,8 @@ void TestWaylandSurface::testScale()
     s->commit(Surface::CommitFlag::None);
     QVERIFY(sizeChangedSpy.wait());
     QCOMPARE(sizeChangedSpy.count(), 1);
-    QCOMPARE(scaleChangedSpy.count(), 1);
-    QCOMPARE(serverSurface->scale(), 2);
+    QCOMPARE(bufferScaleChangedSpy.count(), 1);
+    QCOMPARE(serverSurface->bufferScale(), 2);
     QCOMPARE(serverSurface->size(), QSize(25,25));
 }
 
@@ -856,14 +855,14 @@ void TestWaylandSurface::testUnmapOfNotMappedSurface()
 
     QSignalSpy unmappedSpy(serverSurface, &SurfaceInterface::unmapped);
     QVERIFY(unmappedSpy.isValid());
-    QSignalSpy scaleChanged(serverSurface, &SurfaceInterface::scaleChanged);
+    QSignalSpy bufferScaleChanged(serverSurface, &SurfaceInterface::bufferScaleChanged);
 
     // let's map a null buffer and change scale to trigger a signal we can wait for
     s->attachBuffer(Buffer::Ptr());
     s->setScale(2);
     s->commit(Surface::CommitFlag::None);
 
-    QVERIFY(scaleChanged.wait());
+    QVERIFY(bufferScaleChanged.wait());
     QVERIFY(unmappedSpy.isEmpty());
 }
 
