@@ -24,7 +24,7 @@ public:
     Private(SeatInterface *seat, DataDeviceInterface *q, DataDeviceManagerInterface *manager, wl_resource *parentResource);
     ~Private();
 
-    DataOfferInterface *createDataOffer(DataSourceInterface *source);
+    DataOfferInterface *createDataOffer(AbstractDataSource *source);
 
     SeatInterface *seat;
     DataSourceInterface *source = nullptr;
@@ -149,7 +149,7 @@ void DataDeviceInterface::Private::setSelection(DataSourceInterface *dataSource)
     }
 }
 
-DataOfferInterface *DataDeviceInterface::Private::createDataOffer(DataSourceInterface *source)
+DataOfferInterface *DataDeviceInterface::Private::createDataOffer(AbstractDataSource *source)
 {
     if (!resource) {
         return nullptr;
@@ -209,15 +209,10 @@ DataSourceInterface *DataDeviceInterface::selection() const
     return d->selection;
 }
 
-void DataDeviceInterface::sendSelection(DataDeviceInterface *other)
+void DataDeviceInterface::sendSelection(AbstractDataSource *other)
 {
     Q_D();
-    auto otherSelection = other->selection();
-    if (!otherSelection) {
-        sendClearSelection();
-        return;
-    }
-    auto r = d->createDataOffer(otherSelection);
+    auto r = d->createDataOffer(other);
     if (!r) {
         return;
     }
