@@ -9,13 +9,16 @@
 #include "blur_interface.h"
 #include "compositor_interface.h"
 #include "contrast_interface.h"
+#include "datacontroldevicemanager_v1_interface.h"
 #include "datadevicemanager_interface.h"
 #include "dpms_interface.h"
 #include "eglstream_controller_interface.h"
 #include "fakeinput_interface.h"
 #include "idle_interface.h"
-#include "idleinhibit_interface_p.h"
+#include "idleinhibit_v1_interface_p.h"
+#include "keyboard_shortcuts_inhibit_v1_interface.h"
 #include "keystate_interface.h"
+#include "layershell_v1_interface.h"
 #include "linuxdmabuf_v1_interface.h"
 #include "logging.h"
 #include "output_interface.h"
@@ -27,24 +30,23 @@
 #include "plasmawindowmanagement_interface.h"
 #include "pointerconstraints_interface_p.h"
 #include "pointergestures_interface_p.h"
-#include "qtsurfaceextension_interface.h"
+#include "primaryselectiondevicemanager_v1_interface.h"
 #include "relativepointer_interface_p.h"
-#include "remote_access_interface.h"
 #include "seat_interface.h"
+#include "screencast_v1_interface.h"
 #include "server_decoration_interface.h"
 #include "server_decoration_palette_interface.h"
 #include "shadow_interface.h"
-#include "shell_interface.h"
 #include "slide_interface.h"
 #include "subcompositor_interface.h"
 #include "tablet_interface.h"
 #include "textinput_interface_p.h"
-#include "xdgdecoration_interface.h"
-#include "xdgforeign_interface.h"
-#include "xdgoutput_interface.h"
-#include "xdgshell_stable_interface_p.h"
-#include "xdgshell_v5_interface_p.h"
-#include "xdgshell_v6_interface_p.h"
+#include "viewporter_interface.h"
+#include "xdgdecoration_v1_interface.h"
+#include "xdgforeign_v2_interface.h"
+#include "xdgoutput_v1_interface.h"
+#include "xdgshell_interface.h"
+#include "inputmethod_v1_interface.h"
 
 #include <QCoreApplication>
 #include <QDebug>
@@ -108,14 +110,13 @@ Display::Display(QObject *parent)
     : QObject(parent)
     , d(new Private(this))
 {
+    d->display = wl_display_create();
 }
 
 Display::~Display()
 {
-    terminate();
-    if (d->display) {
-        wl_display_destroy(d->display);
-    }
+    emit aboutToTerminate();
+    wl_display_destroy(d->display);
 }
 
 void Display::Private::flush()
@@ -164,17 +165,15 @@ bool Display::automaticSocketNaming() const
     return d->automaticSocketNaming;
 }
 
-void Display::start(StartMode mode)
+bool Display::start(StartMode mode)
 {
     Q_ASSERT(!d->running);
-    Q_ASSERT(!d->display);
-    d->display = wl_display_create();
     if (mode == StartMode::ConnectToSocket) {
         if (d->automaticSocketNaming) {
             const char *socket = wl_display_add_socket_auto(d->display);
             if (socket == nullptr) {
                 qCWarning(KWAYLAND_SERVER) << "Failed to create Wayland socket";
-                return;
+                return false;
             }
 
             const QString newEffectiveSocketName = QString::fromUtf8(socket);
@@ -184,19 +183,14 @@ void Display::start(StartMode mode)
             }
         } else if (wl_display_add_socket(d->display, qPrintable(d->socketName)) != 0) {
             qCWarning(KWAYLAND_SERVER) << "Failed to create Wayland socket";
-            return;
+            return false;
         }
     }
 
     d->loop = wl_display_get_event_loop(d->display);
     d->installSocketNotifier();
-}
 
-void Display::startLoop()
-{
-    Q_ASSERT(!d->running);
-    Q_ASSERT(d->display);
-    d->installSocketNotifier();
+    return d->running;
 }
 
 void Display::dispatchEvents(int msecTimeout)
@@ -210,19 +204,6 @@ void Display::dispatchEvents(int msecTimeout)
     }
 }
 
-void Display::terminate()
-{
-    if (!d->running) {
-        return;
-    }
-    emit aboutToTerminate();
-    wl_display_terminate(d->display);
-    wl_display_destroy(d->display);
-    d->display = nullptr;
-    d->loop = nullptr;
-    d->setRunning(false);
-}
-
 void Display::Private::setRunning(bool r)
 {
     Q_ASSERT(running != r);
@@ -246,13 +227,6 @@ CompositorInterface *Display::createCompositor(QObject *parent)
     return compositor;
 }
 
-ShellInterface *Display::createShell(QObject *parent)
-{
-    ShellInterface *shell = new ShellInterface(this, parent);
-    connect(this, &Display::aboutToTerminate, shell, [shell] { delete shell; });
-    return shell;
-}
-
 OutputDeviceInterface *Display::createOutputDevice(QObject *parent)
 {
     OutputDeviceInterface *output = new OutputDeviceInterface(this, parent);
@@ -306,20 +280,6 @@ PlasmaWindowManagementInterface *Display::createPlasmaWindowManagement(QObject *
     return wm;
 }
 
-QtSurfaceExtensionInterface *Display::createQtSurfaceExtension(QObject *parent)
-{
-    auto s = new QtSurfaceExtensionInterface(this, parent);
-    connect(this, &Display::aboutToTerminate, s, [s] { delete s; });
-    return s;
-}
-
-RemoteAccessManagerInterface *Display::createRemoteAccessManager(QObject *parent)
-{
-    auto i = new RemoteAccessManagerInterface(this, parent);
-    connect(this, &Display::aboutToTerminate, i, [i] { delete i; });
-    return i;
-}
-
 IdleInterface *Display::createIdle(QObject *parent)
 {
     auto i = new IdleInterface(this, parent);
@@ -376,6 +336,13 @@ ServerSideDecorationManagerInterface *Display::createServerSideDecorationManager
     return d;
 }
 
+ScreencastV1Interface *Display::createScreencastV1Interface(QObject *parent)
+{
+    auto s = new ScreencastV1Interface(this, parent);
+    connect(this, &Display::aboutToTerminate, s, [s] { delete s; });
+    return s;
+}
+
 TextInputManagerInterface *Display::createTextInputManager(const TextInputInterfaceVersion &version, QObject *parent)
 {
     TextInputManagerInterface *t = nullptr;
@@ -393,22 +360,11 @@ TextInputManagerInterface *Display::createTextInputManager(const TextInputInterf
     return t;
 }
 
-XdgShellInterface *Display::createXdgShell(const XdgShellInterfaceVersion &version, QObject *parent)
+XdgShellInterface *Display::createXdgShell(QObject *parent)
 {
-    XdgShellInterface *x = nullptr;
-    switch (version) {
-    case XdgShellInterfaceVersion::UnstableV5:
-        x = new XdgShellV5Interface(this, parent);
-        break;
-    case XdgShellInterfaceVersion::UnstableV6:
-        x = new XdgShellV6Interface(this, parent);
-        break;
-    case XdgShellInterfaceVersion::Stable:
-        x = new XdgShellStableInterface(this, parent);
-        break;
-    }
-    connect(this, &Display::aboutToTerminate, x, [x] { delete x; });
-    return x;
+    XdgShellInterface *shell = new XdgShellInterface(this, parent);
+    connect(this, &Display::aboutToTerminate, shell, [shell] { delete shell; });
+    return shell;
 }
 
 RelativePointerManagerInterface *Display::createRelativePointerManager(const RelativePointerInterfaceVersion &version, QObject *parent)
@@ -447,23 +403,18 @@ PointerConstraintsInterface *Display::createPointerConstraints(const PointerCons
     return p;
 }
 
-XdgForeignInterface *Display::createXdgForeignInterface(QObject *parent)
+XdgForeignV2Interface *Display::createXdgForeignV2Interface(QObject *parent)
 {
-    XdgForeignInterface *foreign = new XdgForeignInterface(this, parent);
+    XdgForeignV2Interface *foreign = new XdgForeignV2Interface(this, parent);
     connect(this, &Display::aboutToTerminate, foreign, [foreign] { delete foreign; });
     return foreign;
 }
 
-IdleInhibitManagerInterface *Display::createIdleInhibitManager(const IdleInhibitManagerInterfaceVersion &version, QObject *parent)
+IdleInhibitManagerV1Interface *Display::createIdleInhibitManagerV1(QObject *parent)
 {
-    IdleInhibitManagerInterface *i = nullptr;
-    switch (version) {
-    case IdleInhibitManagerInterfaceVersion::UnstableV1:
-        i = new IdleInhibitManagerUnstableV1Interface(this, parent);
-        break;
-    }
-    connect(this, &Display::aboutToTerminate, i, [i] { delete i; });
-    return i;
+    IdleInhibitManagerV1Interface *idleManager = new IdleInhibitManagerV1Interface(this, parent);
+    connect(this, &Display::aboutToTerminate, idleManager, [idleManager] { delete idleManager; });
+    return idleManager;
 }
 
 AppMenuManagerInterface *Display::createAppMenuManagerInterface(QObject *parent)
@@ -494,16 +445,16 @@ PlasmaVirtualDesktopManagementInterface *Display::createPlasmaVirtualDesktopMana
     return b;
 }
 
-XdgOutputManagerInterface *Display::createXdgOutputManager(QObject *parent)
+XdgOutputManagerV1Interface *Display::createXdgOutputManagerV1(QObject *parent)
 {
-    auto b = new XdgOutputManagerInterface(this, parent);
+    auto b = new XdgOutputManagerV1Interface(this, parent);
     connect(this, &Display::aboutToTerminate, b, [b] { delete b; });
     return b;
 }
 
-XdgDecorationManagerInterface *Display::createXdgDecorationManager(XdgShellInterface *shellInterface, QObject *parent)
+XdgDecorationManagerV1Interface *Display::createXdgDecorationManagerV1(QObject *parent)
 {
-    auto d = new XdgDecorationManagerInterface(this, shellInterface, parent);
+    auto d = new XdgDecorationManagerV1Interface(this, parent);
     connect(this, &Display::aboutToTerminate, d, [d] { delete d; });
     return d;
 }
@@ -529,6 +480,56 @@ TabletManagerInterface *Display::createTabletManagerInterface(QObject *parent)
     return d;
 }
 
+DataControlDeviceManagerV1Interface *Display::createDataControlDeviceManagerV1(QObject *parent)
+{
+    auto m = new DataControlDeviceManagerV1Interface(this, parent);
+    connect(this, &Display::aboutToTerminate, m, [m] { delete m; });
+    return m;
+}
+
+KeyboardShortcutsInhibitManagerV1Interface *Display::createKeyboardShortcutsInhibitManagerV1(QObject *parent)
+{
+    auto d = new KeyboardShortcutsInhibitManagerV1Interface(this, parent);
+
+    connect(this, &Display::aboutToTerminate, d, [d] { delete d; });
+    return d;
+}
+
+InputMethodV1Interface *Display::createInputMethodInterface(QObject *parent)
+{
+    auto d = new InputMethodV1Interface(this, parent);
+    connect(this, &Display::aboutToTerminate, d, [d] { delete d; });
+    return d;
+}
+
+ViewporterInterface *Display::createViewporter(QObject *parent)
+{
+    auto viewporter = new ViewporterInterface(this, parent);
+    connect(this, &Display::aboutToTerminate, viewporter, [viewporter] { delete viewporter; });
+    return viewporter;
+}
+
+PrimarySelectionDeviceManagerV1Interface *Display::createPrimarySelectionDeviceManagerV1(QObject *parent)
+{
+    auto primarySelection = new PrimarySelectionDeviceManagerV1Interface(this, parent);
+    connect(this, &Display::aboutToTerminate, primarySelection, [primarySelection] { delete primarySelection; });
+    return primarySelection;
+}
+
+InputPanelV1Interface *Display::createInputPanelInterface(QObject *parent)
+{
+    auto p = new InputPanelV1Interface(this, parent);
+    connect(this, &Display::aboutToTerminate, p, [p] { delete p; });
+    return p;
+}
+
+LayerShellV1Interface *Display::createLayerShellV1(QObject *parent)
+{
+    auto shell = new LayerShellV1Interface(this, parent);
+    connect(this, &Display::aboutToTerminate, shell, [shell] { delete shell; });
+    return shell;
+}
+
 void Display::createShm()
 {
     Q_ASSERT(d->display);
