@@ -23,6 +23,7 @@ namespace KWaylandServer
 {
 
 class DataDeviceInterface;
+class AbstractDataSource;
 class Display;
 class SurfaceInterface;
 class TextInputInterface;
@@ -692,8 +693,10 @@ public:
      * @since 5.24
      * @see selectionChanged
      * @see setSelection
+     * This may be null
      **/
-    DataDeviceInterface *selection() const;
+    KWaylandServer::AbstractDataSource *selection() const;
+
     /**
      * This method allows to manually set the @p dataDevice for the current clipboard selection.
      * The clipboard selection is handled automatically in SeatInterface.
@@ -707,7 +710,9 @@ public:
      * @see selectionChanged
      * @since 5.24
      **/
-    void setSelection(DataDeviceInterface *dataDevice);
+    void setSelection(AbstractDataSource *selection);
+
+    void setPrimarySelection(AbstractDataSource *selection);
 
     static SeatInterface *get(wl_resource *native);
 
@@ -736,7 +741,13 @@ Q_SIGNALS:
      * @see selection
      * @see setSelection
      **/
-    void selectionChanged(DataDeviceInterface*);
+    void selectionChanged(KWaylandServer::AbstractDataSource*);
+
+    /**
+     * Emitted whenever the primary selection changes
+     * @see primarySelection
+     **/
+    void primarySelectionChanged(KWaylandServer::AbstractDataSource*);
 
     /**
      * Emitted when a drag'n'drop operation is started
@@ -765,6 +776,8 @@ Q_SIGNALS:
 
 private:
     friend class Display;
+    friend class DataControlDeviceV1Interface;
+    friend class PrimarySelectionDeviceV1Interface;
     friend class DataDeviceManagerInterface;
     friend class TextInputManagerUnstableV0Interface;
     friend class TextInputManagerUnstableV2Interface;
