@@ -19,8 +19,12 @@
 namespace KWaylandServer
 {
 
+class AbstractDataSource;
 class DataDeviceInterface;
+class DataSourceInterface;
+class DataControlDeviceV1Interface;
 class TextInputInterface;
+class PrimarySelectionDeviceV1Interface;
 
 class SeatInterface::Private : public Global::Private
 {
@@ -34,10 +38,11 @@ public:
     QVector<TouchInterface *> touchsForSurface(SurfaceInterface *surface) const;
     QVector<DataDeviceInterface *> dataDevicesForSurface(SurfaceInterface *surface) const;
     TextInputInterface *textInputForSurface(SurfaceInterface *surface) const;
+    void registerPrimarySelectionDevice(PrimarySelectionDeviceV1Interface *primarySelectionDevice);
     void registerDataDevice(DataDeviceInterface *dataDevice);
+    void registerDataControlDevice(DataControlDeviceV1Interface *dataDevice);
     void registerTextInput(TextInputInterface *textInput);
     void endDrag(quint32 serial);
-    void cancelPreviousSelection(DataDeviceInterface *newlySelectedDataDevice);
 
     QString name;
     bool pointer = false;
@@ -49,8 +54,14 @@ public:
     QVector<KeyboardInterface*> keyboards;
     QVector<TouchInterface*> touchs;
     QVector<DataDeviceInterface*> dataDevices;
+    QVector<PrimarySelectionDeviceV1Interface*> primarySelectionDevices;
+    QVector<DataControlDeviceV1Interface*> dataControlDevices;
+
     QVector<TextInputInterface*> textInputs;
-    DataDeviceInterface *currentSelection = nullptr;
+
+    // the last thing copied into the clipboard content
+    AbstractDataSource *currentSelection = nullptr;
+    AbstractDataSource *currentPrimarySelection = nullptr;
 
     // Pointer related members
     struct Pointer {
@@ -102,6 +113,7 @@ public:
             QMetaObject::Connection destroyConnection;
             quint32 serial = 0;
             QVector<DataDeviceInterface *> selections;
+            QVector<PrimarySelectionDeviceV1Interface *> primarySelections;
         };
         Focus focus;
         quint32 lastStateSerial = 0;
@@ -165,7 +177,8 @@ private:
     void getPointer(wl_client *client, wl_resource *resource, uint32_t id);
     void getKeyboard(wl_client *client, wl_resource *resource, uint32_t id);
     void getTouch(wl_client *client, wl_resource *resource, uint32_t id);
-    void updateSelection(DataDeviceInterface *dataDevice, bool set);
+    void updateSelection(DataDeviceInterface *dataDevice);
+    void updatePrimarySelection(PrimarySelectionDeviceV1Interface *primarySelectionDevice);
     static Private *cast(wl_resource *r);
     static void unbind(wl_resource *r);
 
