@@ -20,8 +20,15 @@ public:
     explicit SurfaceRole(SurfaceInterface *surface);
     virtual ~SurfaceRole();
 
+    const QPointer<SurfaceInterface> &surface() const
+    {
+        return m_surface;
+    }
+
     virtual void commit() = 0;
 
+    static SurfaceRole *get(SurfaceInterface *surface);
+
 private:
     QPointer<SurfaceInterface> m_surface;
 
